==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/datatransfer/dnd/DragSourceDropEvent.hpp <==
#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_
#define _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HDL_
#include "com/sun/star/datatransfer/dnd/DragSourceDropEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEEVENT_HPP_
#include "com/sun/star/datatransfer/dnd/DragSourceEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace datatransfer { namespace dnd {

inline DragSourceDropEvent::DragSourceDropEvent() SAL_THROW( () )
    : ::com::sun::star::datatransfer::dnd::DragSourceEvent()
    , DropAction(0)
    , DropSuccess(false)
{
}

inline DragSourceDropEvent::DragSourceDropEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::dnd::XDragSourceContext >& DragSourceContext_, const ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::dnd::XDragSource >& DragSource_, const ::sal_Int8& DropAction_, const ::sal_Bool& DropSuccess_) SAL_THROW( () )
    : ::com::sun::star::datatransfer::dnd::DragSourceEvent(Source_, DragSourceContext_, DragSource_)
    , DropAction(DropAction_)
    , DropSuccess(DropSuccess_)
{
}

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::datatransfer::dnd::DragSourceDropEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.datatransfer.dnd.DragSourceDropEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/datatransfer/dnd/DragSourceDropEvent.hpp <==
#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_
#define _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HDL_
#include "com/sun/star/datatransfer/dnd/DragSourceDropEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEEVENT_HPP_
#include "com/sun/star/datatransfer/dnd/DragSourceEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace datatransfer { namespace dnd {

inline DragSourceDropEvent::DragSourceDropEvent() SAL_THROW( () )
    : ::com::sun::star::datatransfer::dnd::DragSourceEvent()
    , DropAction(0)
    , DropSuccess(false)
{
}

inline DragSourceDropEvent::DragSourceDropEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::dnd::XDragSourceContext >& DragSourceContext_, const ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::dnd::XDragSource >& DragSource_, const ::sal_Int8& DropAction_, const ::sal_Bool& DropSuccess_) SAL_THROW( () )
    : ::com::sun::star::datatransfer::dnd::DragSourceEvent(Source_, DragSourceContext_, DragSource_)
    , DropAction(DropAction_)
    , DropSuccess(DropSuccess_)
{
}

} } } } }

namespace com { namespace sun { namespace star { namespace datatransfer { namespace dnd {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::datatransfer::dnd::DragSourceDropEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.datatransfer.dnd.DragSourceDropEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::datatransfer::dnd::DragSourceDropEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::datatransfer::dnd::DragSourceDropEvent >::get();
}

#endif // _COM_SUN_STAR_DATATRANSFER_DND_DRAGSOURCEDROPEVENT_HPP_
